/*
 * tape.h  -- An HP-2000 Timeshared BASIC System tape manipulation program.
 *
 * Copyright (c) Scott G. Taylor
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * SCOTT G. TAYLOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this notice, the name of Scott G. Taylor shall not
 * be used in advertising or otherwise to promote the sale, use or other dealings
 * in this Software without prior written authorization from Scott G. Taylor.
 */

#include <fcntl.h>

struct tapeinfo {
	int		fd;		/* file descriptor */
	char		*devnam;	/* Device or file path and name */
	uint8_t		type; 		/* SCSI, tpc, tpf, e11, simh, other */
	uint32_t	flags;		/* R/O, FIFO, WRONLY */
	uint32_t	fileno;		/* Current logical file number */
	uint32_t	recno;		/* Current logical record number */
	uint32_t	curpos;		/* Current raw byte position */
	uint32_t	reqbytes;	/* Requested read/write byte count */
	uint32_t	actbytes;	/* Actual bytes read/written */
	uint32_t	maxbsize;	/* Maximum block size, host dependent */
	uint32_t	status; 	/* ERROR (see ext_status), EOF, EOT, SRL (Short read) */
	uint32_t	ext_status; 	/* HDW error (see hdw_error), RLE (rec too big), FULL (no space) */
					/* SIMERR (Simulated tape record length mismatch */
	uint32_t	hdw_error;	/* Hardware error status - hardware specific */
	uint32_t	nerrors;	/* Error tally */
	uint32_t	debug;		/* Driver debug flag */
};

#define	MAX_TAPE_RECLEN		32768

#define	TAPEIO_TYPE_UNDEFINED	0
#define TAPEIO_TYPE_SCSI	1
#define TAPEIO_TYPE_TPC		2
#define TAPEIO_TYPE_TPF		3
#define TAPEIO_TYPE_E11		4
#define TAPEIO_TYPE_SIMH	5
#define	TAPEIO_TYPE_OTHER	9

#define TAPEIO_STATUS_EOF	0x01
#define TAPEIO_STATUS_EOT	0x02
#define TAPEIO_STATUS_ERROR	0x80

#define TAPEIO_EXT_STATUS_HDW	0x01
#define TAPEIO_EXT_STATUS_RLE	0x02
#define TAPEIO_EXT_STATUS_FULL	0x03

#define TAPEIO_FLAG_RO		0x01
#define TAPEIO_FLAG_FIFO	0x02
#define	TAPEIO_FLAG_WRONLY	0x03

int32_t tape_read (struct tapeinfo *, uint8_t *, uint32_t);
int32_t	tape_write_open (struct tapeinfo *, uint8_t *);
int32_t	tape_write (struct tapeinfo *, uint8_t *, uint32_t);
int32_t	tape_write_eof (struct tapeinfo *);
int32_t	tape_close (struct tapeinfo *);
